@@ -14,7 +14,7 @@
 
 from __future__ import print_function, absolute_import
 
-if __name__=='pymol.viewing':
+if True:
 
     import sys
     if sys.version_info[0] == 2:
@@ -23,7 +23,6 @@ if __name__=='pymol.viewing':
         import _thread as thread
 
     import threading
-    import types
     import traceback
     import pymol
     from . import selector
@@ -1072,6 +1071,12 @@ SEE ALSO
         with _self.lockcm:
             return _cmd.scene_order(_self._COb, names, sort, location)
 
+    def _scene_get_current_message(_self=cmd):
+        wiz = _self.get_wizard()
+        return '\n'.join(wiz.message) if (wiz is not None
+                and wiz.__class__.__name__ == 'Message'
+                and hasattr(wiz, 'from_scene')) else None
+
     def scene_recall_message(message, _self=cmd):
         '''
         INTERNAL, DO NOT USE.
@@ -1155,6 +1160,11 @@ SEE ALSO
             if action == 'recall':
                 action = 'next'
 
+        # preserve message on update
+        if action == 'update':
+            if message is None:
+                message = _scene_get_current_message(_self)
+
         # aliases (DEPRECATED)
         if action == 'clear':
             action = 'delete'
